@@ -27,10 +27,10 @@ import (
 
 	"github.com/GoogleContainerTools/skaffold/cmd/skaffold/app/flags"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
-	deployutil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/graph"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/debugging"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/manifest"
+	rUtil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/render/renderer/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
@@ -42,7 +42,7 @@ var doFilter = runFilter
 
 // NewCmdFilter describes the CLI command to filter and transform a set of Kubernetes manifests.
 func NewCmdFilter() *cobra.Command {
-	var debuggingFilters, transform bool
+	var debuggingFilters bool
 	var renderFromBuildOutputFile flags.BuildOutputFileFlag
 
 	return NewCmd("filter").
@@ -53,16 +53,15 @@ func NewCmdFilter() *cobra.Command {
 		WithFlags([]*Flag{
 			{Value: &renderFromBuildOutputFile, Name: "build-artifacts", Shorthand: "a", Usage: "File containing build result from a previous 'skaffold build --file-output'"},
 			{Value: &debuggingFilters, Name: "debugging", DefValue: false, Usage: `Apply debug transforms similar to "skaffold debug"`, IsEnum: true},
-			{Value: &transform, Name: "transform", DefValue: false, Usage: `(experimental) Replace images in manifest and set labels`, IsEnum: true},
 		}).
 		NoArgs(func(ctx context.Context, out io.Writer) error {
-			return doFilter(ctx, out, debuggingFilters, renderFromBuildOutputFile.BuildArtifacts(), transform)
+			return doFilter(ctx, out, debuggingFilters, renderFromBuildOutputFile.BuildArtifacts())
 		})
 }
 
 // runFilter loads the Kubernetes manifests from stdin and applies the debug transformations.
 // Unlike `skaffold debug`, this filtering affects all images and not just the built artifacts.
-func runFilter(ctx context.Context, out io.Writer, debuggingFilters bool, buildArtifacts []graph.Artifact, transform bool) error {
+func runFilter(ctx context.Context, out io.Writer, debuggingFilters bool, buildArtifacts []graph.Artifact) error {
 	return withRunner(ctx, out, func(r runner.Runner, configs []util.VersionedConfig) error {
 		manifestList, err := manifest.Load(os.Stdin)
 		if err != nil {
@@ -70,16 +69,15 @@ func runFilter(ctx context.Context, out io.Writer, debuggingFilters bool, buildA
 		}
 
 		allow, deny := getTransformList(configs)
-		if transform {
-			manifestList, err = manifestList.SetLabels(pkgutil.EnvSliceToMap(opts.CustomLabels, "="),
-				manifest.NewResourceSelectorLabels(allow, deny))
-			if err != nil {
-				return err
-			}
-			manifestList, err = manifestList.ReplaceImages(ctx, buildArtifacts, manifest.NewResourceSelectorImages(allow, deny))
-			if err != nil {
-				return err
-			}
+
+		manifestList, err = manifestList.SetLabels(pkgutil.EnvSliceToMap(opts.CustomLabels, "="),
+			manifest.NewResourceSelectorLabels(allow, deny))
+		if err != nil {
+			return err
+		}
+		manifestList, err = manifestList.ReplaceImages(ctx, buildArtifacts, manifest.NewResourceSelectorImages(allow, deny))
+		if err != nil {
+			return err
 		}
 
 		if debuggingFilters {
@@ -116,21 +114,21 @@ func getTransformList(configs []util.VersionedConfig) (map[apim.GroupKind]latest
 	// add default values
 	for _, rf := range manifest.TransformAllowlist {
 		groupKind := apim.ParseGroupKind(rf.GroupKind)
-		allow[groupKind] = deployutil.ConvertJSONPathIndex(rf)
+		allow[groupKind] = rUtil.ConvertJSONPathIndex(rf)
 	}
 	for _, rf := range manifest.TransformDenylist {
 		groupKind := apim.ParseGroupKind(rf.GroupKind)
-		allow[groupKind] = deployutil.ConvertJSONPathIndex(rf)
+		allow[groupKind] = rUtil.ConvertJSONPathIndex(rf)
 	}
 
 	for _, cfg := range configs {
 		for _, rf := range cfg.(*latest.SkaffoldConfig).ResourceSelector.Allow {
 			groupKind := apim.ParseGroupKind(rf.GroupKind)
-			allow[groupKind] = deployutil.ConvertJSONPathIndex(rf)
+			allow[groupKind] = rUtil.ConvertJSONPathIndex(rf)
 		}
 		for _, rf := range cfg.(*latest.SkaffoldConfig).ResourceSelector.Deny {
 			groupKind := apim.ParseGroupKind(rf.GroupKind)
-			deny[groupKind] = deployutil.ConvertJSONPathIndex(rf)
+			deny[groupKind] = rUtil.ConvertJSONPathIndex(rf)
 		}
 	}
 	return allow, deny
