@@ -40,6 +40,7 @@ var (
 	analyze                  bool
 	enableJibInit            bool
 	enableJibGradleInit      bool
+	enableKoInit             bool
 	enableBuildpacksInit     bool
 	enableNewInitFormat      bool
 	enableManifestGeneration bool
@@ -65,6 +66,7 @@ func NewCmdInit() *cobra.Command {
 			{Value: &enableNewInitFormat, Name: "XXenableNewInitFormat", DefValue: false, Usage: "", Hidden: true, IsEnum: true},
 			{Value: &enableJibInit, Name: "XXenableJibInit", DefValue: true, Usage: "", Hidden: true, IsEnum: true},
 			{Value: &enableJibGradleInit, Name: "XXenableJibGradleInit", DefValue: false, Usage: "", Hidden: true, IsEnum: true},
+			{Value: &enableKoInit, Name: "XXenableKoInit", DefValue: false, Usage: "", Hidden: true, IsEnum: true},
 			{Value: &enableBuildpacksInit, Name: "XXenableBuildpacksInit", DefValue: true, Usage: "", Hidden: true, IsEnum: true},
 			{Value: &buildpacksBuilder, Name: "XXdefaultBuildpacksBuilder", DefValue: "gcr.io/buildpacks/builder:v1", Usage: "", Hidden: true},
 			{Value: &enableManifestGeneration, Name: "generate-manifests", DefValue: false, Usage: "Allows skaffold to try and generate basic kubernetes resources to get your project started", IsEnum: true},
@@ -85,8 +87,9 @@ func doInit(ctx context.Context, out io.Writer) error {
 		Analyze:                  analyze,
 		EnableJibInit:            enableJibInit,
 		EnableJibGradleInit:      enableJibGradleInit,
+		EnableKoInit:             enableKoInit,
 		EnableBuildpacksInit:     enableBuildpacksInit,
-		EnableNewInitFormat:      enableNewInitFormat || enableBuildpacksInit || enableJibInit,
+		EnableNewInitFormat:      enableNewInitFormat || enableBuildpacksInit || enableJibInit || enableKoInit,
 		EnableManifestGeneration: enableManifestGeneration,
 		Opts:                     opts,
 		MaxFileSize:              maxFileSize,
