@@ -54,6 +54,7 @@ func TestFlagsToConfigVersion(t *testing.T) {
 				Analyze:                false,
 				EnableJibInit:          true,
 				EnableJibGradleInit:    false,
+				EnableKoInit:           false,
 				EnableBuildpacksInit:   true,
 				EnableNewInitFormat:    true,
 				BuildpacksBuilder:      "gcr.io/buildpacks/builder:v1",
@@ -77,6 +78,7 @@ func TestFlagsToConfigVersion(t *testing.T) {
 				"--analyze",
 				"--XXenableJibInit",
 				"--XXenableJibGradleInit",
+				"--XXenableKoInit=true",
 				"--XXenableBuildpacksInit",
 				"--XXenableNewInitFormat",
 				"--XXdefaultBuildpacksBuilder", "buildpacks/builder",
@@ -91,6 +93,7 @@ func TestFlagsToConfigVersion(t *testing.T) {
 				Analyze:                true,
 				EnableJibInit:          true,
 				EnableJibGradleInit:    true,
+				EnableKoInit:           true,
 				EnableBuildpacksInit:   true,
 				EnableNewInitFormat:    true,
 				BuildpacksBuilder:      "buildpacks/builder",
@@ -104,6 +107,8 @@ func TestFlagsToConfigVersion(t *testing.T) {
 			args: []string{
 				"init",
 				"--XXenableJibInit",
+				"--XXenableKoInit=false",
+				"--XXenableBuildpacksInit=false",
 			},
 			expectedConfig: config.Config{
 				ComposeFile:            "",
@@ -114,7 +119,33 @@ func TestFlagsToConfigVersion(t *testing.T) {
 				Force:                  false,
 				Analyze:                false,
 				EnableJibInit:          true,
-				EnableBuildpacksInit:   true,
+				EnableKoInit:           false,
+				EnableBuildpacksInit:   false,
+				EnableNewInitFormat:    true,
+				BuildpacksBuilder:      "gcr.io/buildpacks/builder:v1",
+				Opts:                   opts,
+				MaxFileSize:            maxFileSize,
+			},
+		},
+		{
+			name: "enableKoInit implies enableNewInitFormat",
+			args: []string{
+				"init",
+				"--XXenableJibInit=false",
+				"--XXenableKoInit",
+				"--XXenableBuildpacksInit=false",
+			},
+			expectedConfig: config.Config{
+				ComposeFile:            "",
+				CliArtifacts:           []string{},
+				CliKubernetesManifests: []string{},
+				SkipBuild:              false,
+				SkipDeploy:             false,
+				Force:                  false,
+				Analyze:                false,
+				EnableJibInit:          false,
+				EnableKoInit:           true,
+				EnableBuildpacksInit:   false,
 				EnableNewInitFormat:    true,
 				BuildpacksBuilder:      "gcr.io/buildpacks/builder:v1",
 				Opts:                   opts,
@@ -125,6 +156,8 @@ func TestFlagsToConfigVersion(t *testing.T) {
 			name: "enableBuildpackInit implies enableNewInitFormat",
 			args: []string{
 				"init",
+				"--XXenableJibInit=false",
+				"--XXenableKoInit=false",
 				"--XXenableBuildpacksInit",
 			},
 			expectedConfig: config.Config{
@@ -135,7 +168,8 @@ func TestFlagsToConfigVersion(t *testing.T) {
 				SkipDeploy:             false,
 				Force:                  false,
 				Analyze:                false,
-				EnableJibInit:          true,
+				EnableJibInit:          false,
+				EnableKoInit:           false,
 				EnableBuildpacksInit:   true,
 				EnableNewInitFormat:    true,
 				BuildpacksBuilder:      "gcr.io/buildpacks/builder:v1",
