@@ -24,13 +24,15 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 )
 
-type timing struct {
+type Timing struct {
 	name string
 	time float64
 }
 
 // we'll need to regenerate this list time to time
-var timings = []timing{
+
+// Timings contains the timings for tests marked with CanRunWithoutGcp
+var Timings = []Timing{
 	{"TestRun", 183.68},
 	{"TestDebug", 128.16},
 	{"TestDevAPITriggers", 81.05},
@@ -78,15 +80,15 @@ var timings = []timing{
 	{"TestConfigListForAll", 0.03},
 }
 
-const maxTime = 300.0
+const MaxBinTime = 300.0
 
 type bin struct {
 	size  int
 	total float64
 }
 
-func (b *bin) Add(t timing) bool {
-	if b.total+t.time > maxTime {
+func (b *bin) Add(t Timing, maxBinTime float64) bool {
+	if b.total+t.time > maxBinTime {
 		return false
 	}
 	b.total += t.time
@@ -98,7 +100,7 @@ func (b *bin) String() string {
 	return fmt.Sprintf("total: %f, size: %d", b.total, b.size)
 }
 
-func Partitions() (map[string]int, int) {
+func Partitions(timings []Timing, maxBinTime float64) (map[string]int, int) {
 	// binpack with first fit decreasing
 	sort.Slice(timings, func(i, j int) bool {
 		return timings[i].time > timings[j].time
@@ -110,7 +112,7 @@ func Partitions() (map[string]int, int) {
 	for _, timing := range timings {
 		fit := false
 		for i := range bins {
-			if bins[i].Add(timing) {
+			if bins[i].Add(timing, maxBinTime) {
 				result[timing.name] = i
 				fit = true
 				break
@@ -119,12 +121,13 @@ func Partitions() (map[string]int, int) {
 		if !fit {
 			newBin := &bin{}
 			bins = append(bins, newBin)
-			if !newBin.Add(timing) {
-				panic(fmt.Errorf("can't fit %v into max bucket size %f", timing, maxTime))
+			if !newBin.Add(timing, maxBinTime) {
+				panic(fmt.Errorf("can't fit %v into max bucket size %f", timing, maxBinTime))
 			}
 			result[timing.name] = len(bins) - 1
 		}
 	}
+
 	if log.IsTraceLevelEnabled() {
 		ctx := context.TODO()
 		log.Entry(ctx).Trace("Partitions: ")
