@@ -77,6 +77,11 @@ func Deploy(args ...string) *RunBuilder {
 	return withDefaults("deploy", args)
 }
 
+// Verify runs `skaffold verify` with the given arguments.
+func Verify(args ...string) *RunBuilder {
+	return withDefaults("verify", args)
+}
+
 // Debug runs `skaffold debug` with the given arguments.
 func Debug(args ...string) *RunBuilder {
 	return withDefaults("debug", args)
@@ -230,16 +235,10 @@ func (b *RunBuilder) runForked(t *testing.T, out io.Writer) {
 	cmd.Stdout = out
 	t.Logf("Running %s in %s", cmd.Args, cmd.Dir)
 
-	start := time.Now()
 	if err := cmd.Start(); err != nil {
 		t.Fatalf("skaffold %s: %v", b.command, err)
 	}
 
-	go func() {
-		cmd.Wait()
-		t.Logf("Ran %s in %v", cmd.Args, timeutil.Humanize(time.Since(start)))
-	}()
-
 	waitAndTriggerStacktrace(ctx, t, cmd.Process)
 
 	t.Cleanup(func() {
