@@ -18,10 +18,11 @@ package v2
 
 import proto "github.com/GoogleContainerTools/skaffold/proto/v2"
 
-func ApplicationLog(podName, containerName, message, formattedMessage string) {
+func ApplicationLog(podName, containerName, prefix, message, formattedMessage string) {
 	handler.handleApplicationLogEvent(&proto.ApplicationLogEvent{
-		ContainerName:        podName,
-		PodName:              containerName,
+		ContainerName:        containerName,
+		PodName:              podName,
+		Prefix:               prefix,
 		Message:              message,
 		RichFormattedMessage: formattedMessage,
 	})
