@@ -16,6 +16,8 @@ limitations under the License.
 
 package v2
 
+//nolint:golint,staticcheck
+
 import (
 	"bytes"
 	"fmt"
@@ -24,8 +26,6 @@ import (
 	"sync"
 
 	"github.com/acarl005/stripansi"
-
-	//nolint:golint,staticcheck
 	"github.com/golang/protobuf/jsonpb"
 	"github.com/mitchellh/go-homedir"
 	"google.golang.org/protobuf/types/known/timestamppb"
@@ -255,6 +255,11 @@ func (ev *eventHandler) handleExec(event *proto.Event) {
 		ev.stateLock.Lock()
 		ev.state.RenderState.Status = te.Status
 		ev.stateLock.Unlock()
+	case *proto.Event_VerifyEvent:
+		te := e.VerifyEvent
+		ev.stateLock.Lock()
+		ev.state.VerifyState.Status = te.Status
+		ev.stateLock.Unlock()
 	case *proto.Event_DeploySubtaskEvent:
 		de := e.DeploySubtaskEvent
 		ev.stateLock.Lock()
