@@ -33,7 +33,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubectl"
 	kubernetesclient "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/client"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/log"
-	v1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
@@ -41,41 +41,41 @@ import (
 func TestSyncHooks(t *testing.T) {
 	testutil.Run(t, "TestSyncHooks", func(t *testutil.T) {
 		workDir, _ := filepath.Abs("./foo")
-		hooks := v1.SyncHooks{
-			PreHooks: []v1.SyncHookItem{
+		hooks := latest.SyncHooks{
+			PreHooks: []latest.SyncHookItem{
 				{
-					HostHook: &v1.HostHook{
+					HostHook: &latest.HostHook{
 						OS:      []string{"linux", "darwin"},
 						Command: []string{"sh", "-c", "echo pre-hook running with SKAFFOLD_IMAGE=$SKAFFOLD_IMAGE,SKAFFOLD_BUILD_CONTEXT=$SKAFFOLD_BUILD_CONTEXT,SKAFFOLD_FILES_ADDED_OR_MODIFIED=$SKAFFOLD_FILES_ADDED_OR_MODIFIED,SKAFFOLD_FILES_DELETED=$SKAFFOLD_FILES_DELETED,SKAFFOLD_KUBE_CONTEXT=$SKAFFOLD_KUBE_CONTEXT,SKAFFOLD_NAMESPACES=$SKAFFOLD_NAMESPACES"},
 					},
 				},
 				{
-					HostHook: &v1.HostHook{
+					HostHook: &latest.HostHook{
 						OS:      []string{"windows"},
 						Command: []string{"cmd.exe", "/C", "echo pre-hook running with SKAFFOLD_IMAGE=%SKAFFOLD_IMAGE%,SKAFFOLD_BUILD_CONTEXT=%SKAFFOLD_BUILD_CONTEXT%,SKAFFOLD_FILES_ADDED_OR_MODIFIED=%SKAFFOLD_FILES_ADDED_OR_MODIFIED%,SKAFFOLD_FILES_DELETED=%SKAFFOLD_FILES_DELETED%,SKAFFOLD_KUBE_CONTEXT=%SKAFFOLD_KUBE_CONTEXT%,SKAFFOLD_NAMESPACES=%SKAFFOLD_NAMESPACES%"},
 					},
 				},
 				{
-					ContainerHook: &v1.ContainerHook{
+					ContainerHook: &latest.ContainerHook{
 						Command: []string{"foo", "pre-hook"},
 					},
 				},
 			},
-			PostHooks: []v1.SyncHookItem{
+			PostHooks: []latest.SyncHookItem{
 				{
-					HostHook: &v1.HostHook{
+					HostHook: &latest.HostHook{
 						OS:      []string{"linux", "darwin"},
 						Command: []string{"sh", "-c", "echo post-hook running with SKAFFOLD_IMAGE=$SKAFFOLD_IMAGE,SKAFFOLD_BUILD_CONTEXT=$SKAFFOLD_BUILD_CONTEXT,SKAFFOLD_FILES_ADDED_OR_MODIFIED=$SKAFFOLD_FILES_ADDED_OR_MODIFIED,SKAFFOLD_FILES_DELETED=$SKAFFOLD_FILES_DELETED,SKAFFOLD_KUBE_CONTEXT=$SKAFFOLD_KUBE_CONTEXT,SKAFFOLD_NAMESPACES=$SKAFFOLD_NAMESPACES"},
 					},
 				},
 				{
-					HostHook: &v1.HostHook{
+					HostHook: &latest.HostHook{
 						OS:      []string{"windows"},
 						Command: []string{"cmd.exe", "/C", "echo post-hook running with SKAFFOLD_IMAGE=%SKAFFOLD_IMAGE%,SKAFFOLD_BUILD_CONTEXT=%SKAFFOLD_BUILD_CONTEXT%,SKAFFOLD_FILES_ADDED_OR_MODIFIED=%SKAFFOLD_FILES_ADDED_OR_MODIFIED%,SKAFFOLD_FILES_DELETED=%SKAFFOLD_FILES_DELETED%,SKAFFOLD_KUBE_CONTEXT=%SKAFFOLD_KUBE_CONTEXT%,SKAFFOLD_NAMESPACES=%SKAFFOLD_NAMESPACES%"},
 					},
 				},
 				{
-					ContainerHook: &v1.ContainerHook{
+					ContainerHook: &latest.ContainerHook{
 						Command: []string{"foo", "post-hook"},
 					},
 				},
@@ -86,10 +86,10 @@ func TestSyncHooks(t *testing.T) {
 		postHostHookOut := fmt.Sprintf("post-hook running with SKAFFOLD_IMAGE=gcr.io/foo/img1:latest,SKAFFOLD_BUILD_CONTEXT=%s,SKAFFOLD_FILES_ADDED_OR_MODIFIED=foo1;bar1,SKAFFOLD_FILES_DELETED=foo2;bar2,SKAFFOLD_KUBE_CONTEXT=context1,SKAFFOLD_NAMESPACES=np1,np2", workDir)
 		postContainerHookOut := "container post-hook succeeded"
 
-		artifact := &v1.Artifact{
+		artifact := &latest.Artifact{
 			ImageName: "img1",
 			Workspace: workDir,
-			Sync: &v1.Sync{
+			Sync: &latest.Sync{
 				LifecycleHooks: hooks,
 			},
 		}
