@@ -20,8 +20,6 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
-	"net/http"
 	"os"
 	"strings"
 	"testing"
@@ -30,7 +28,7 @@ import (
 	"go.opentelemetry.io/otel/exporters/stdout"
 	"go.opentelemetry.io/otel/sdk/metric/controller/basic"
 
-	"github.com/GoogleContainerTools/skaffold/cmd/skaffold/app/cmd/statik"
+	"github.com/GoogleContainerTools/skaffold/fs"
 	"github.com/GoogleContainerTools/skaffold/proto/v1"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
@@ -106,9 +104,9 @@ func TestExportMetrics(t *testing.T) {
 		Duration:                     time.Minute * 4,
 	}
 	metersBytes, _ := json.Marshal([]skaffoldMeter{buildMeter, devMeter, debugMeter})
-	fs := &testutil.FakeFileSystem{
+	fakeFS := testutil.FakeFileSystem{
 		Files: map[string][]byte{
-			"/secret/keys.json": []byte(testKey),
+			"assets/secrets_generated/keys.json": []byte(testKey),
 		},
 	}
 
@@ -166,7 +164,7 @@ func TestExportMetrics(t *testing.T) {
 			filename := "metrics"
 			openTelFilename := "otel_metrics"
 
-			t.Override(&statik.FS, func() (http.FileSystem, error) { return fs, nil })
+			fs.AssetsFS = fakeFS
 			t.Override(&isOnline, test.isOnline)
 
 			if test.isOnline {
@@ -188,7 +186,7 @@ func TestExportMetrics(t *testing.T) {
 			}
 
 			_ = exportMetrics(context.Background(), tmp.Path(filename), test.meter)
-			b, err := ioutil.ReadFile(tmp.Path(filename))
+			b, err := os.ReadFile(tmp.Path(filename))
 
 			if !test.isOnline {
 				_ = json.Unmarshal(b, &actual)
@@ -199,7 +197,7 @@ func TestExportMetrics(t *testing.T) {
 				t.CheckDeepEqual(expected, actual)
 			} else {
 				t.CheckDeepEqual(true, os.IsNotExist(err))
-				b, err := ioutil.ReadFile(tmp.Path(openTelFilename))
+				b, err := os.ReadFile(tmp.Path(openTelFilename))
 				t.CheckError(false, err)
 				checkOutput(t, append(savedMetrics, test.meter), b)
 			}
@@ -217,7 +215,7 @@ func TestInitCloudMonitoring(t *testing.T) {
 		{
 			name: "if key present pusher is not nil",
 			fileSystem: &testutil.FakeFileSystem{
-				Files: map[string][]byte{"/secret/keys.json": []byte(testKey)},
+				Files: map[string][]byte{"assets/secrets_generated/keys.json": []byte(testKey)},
 			},
 		},
 		{
@@ -231,7 +229,7 @@ func TestInitCloudMonitoring(t *testing.T) {
 			name: "credentials without project_id returns an error",
 			fileSystem: &testutil.FakeFileSystem{
 				Files: map[string][]byte{
-					"/secret/keys.json": []byte(`{
+					"assets/secrets_generated/keys.json": []byte(`{
 						"client_id": "test_id",
 						"client_secret": "test_secret",
 						"refresh_token": "test_token",
@@ -245,7 +243,7 @@ func TestInitCloudMonitoring(t *testing.T) {
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.name, func(t *testutil.T) {
-			t.Override(&statik.FS, func() (http.FileSystem, error) { return test.fileSystem, nil })
+			fs.AssetsFS = test.fileSystem
 
 			p, err := initCloudMonitoringExporterMetrics()
 
@@ -255,7 +253,7 @@ func TestInitCloudMonitoring(t *testing.T) {
 }
 
 func TestUserMetricReported(t *testing.T) {
-	fs := &testutil.FakeFileSystem{
+	fakeFS := &testutil.FakeFileSystem{
 		Files: map[string][]byte{
 			"/secret/keys.json": []byte(testKey),
 		},
@@ -370,7 +368,7 @@ func TestUserMetricReported(t *testing.T) {
 			filename := "metrics"
 			openTelFilename := "otel_metrics"
 
-			t.Override(&statik.FS, func() (http.FileSystem, error) { return fs, nil })
+			fs.AssetsFS = fakeFS
 			t.Override(&isOnline, true)
 			tmpFile, err := os.OpenFile(tmp.Path(openTelFilename), os.O_RDWR|os.O_CREATE, os.ModePerm)
 			if err != nil {
@@ -386,7 +384,7 @@ func TestUserMetricReported(t *testing.T) {
 
 			_ = exportMetrics(context.Background(), tmp.Path(filename), test.meter)
 
-			b, err := ioutil.ReadFile(tmp.Path(openTelFilename))
+			b, err := os.ReadFile(tmp.Path(openTelFilename))
 			t.CheckNoError(err)
 			checkUser(t, test.expectedUser, b)
 		})
