@@ -14,6 +14,8 @@ See the License for the specific language governing permissions and
 limitations under the License.
 */
 
+// Includes code from github.com/sirupsen/logrus (MIT License)
+
 package log
 
 import (
@@ -28,25 +30,85 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 )
 
-// DefaultLogLevel is logrus warn level
-const DefaultLogLevel = logrus.WarnLevel
+// Logging levels. Defining our own so we can encapsulate the underlying logger implementation.
+const (
+	// PanicLevel level, highest level of severity. Logs and then calls panic with the
+	// message passed to Debug, Info, ...
+	PanicLevel Level = iota
+	// FatalLevel level. Logs and then calls `logger.Exit(1)`. It will exit even if the
+	// logging level is set to Panic.
+	FatalLevel
+	// ErrorLevel level. Logs. Used for errors that should definitely be noted.
+	// Commonly used for hooks to send errors to an error tracking service.
+	ErrorLevel
+	// WarnLevel level. Non-critical entries that deserve eyes.
+	WarnLevel
+	// InfoLevel level. General operational entries about what's going on inside the
+	// application.
+	InfoLevel
+	// DebugLevel level. Usually only enabled when debugging. Very verbose logging.
+	DebugLevel
+	// TraceLevel level. Designates finer-grained informational events than the Debug.
+	TraceLevel
+)
+
+// Level type for logging levels
+type Level uint32
+
+// AllLevels exposes all logging levels
+var AllLevels = []Level{
+	PanicLevel,
+	FatalLevel,
+	ErrorLevel,
+	WarnLevel,
+	InfoLevel,
+	DebugLevel,
+	TraceLevel,
+}
+
+// DefaultLogLevel for the global Skaffold logger
+const DefaultLogLevel = WarnLevel
 
 type contextKey struct{}
 
-var AllLevels = logrus.AllLevels
 var ContextKey = contextKey{}
 
+// logger is the global logrus.Logger for Skaffold
+// TODO: Make this not global.
+var logger = New()
+
 type EventContext struct {
 	Task    constants.Phase
 	Subtask string
 }
 
+// String converts the Level to a string. E.g. PanicLevel becomes "panic".
+func (level Level) String() string {
+	switch level {
+	case TraceLevel:
+		return "trace"
+	case DebugLevel:
+		return "debug"
+	case InfoLevel:
+		return "info"
+	case WarnLevel:
+		return "warning"
+	case ErrorLevel:
+		return "error"
+	case FatalLevel:
+		return "fatal"
+	case PanicLevel:
+		return "panic"
+	}
+	return "unknown"
+}
+
 // Entry takes an context.Context and constructs a logrus.Entry from it, adding
 // fields for task and subtask information
 func Entry(ctx context.Context) *logrus.Entry {
 	val := ctx.Value(ContextKey)
 	if eventContext, ok := val.(EventContext); ok {
-		return logrus.WithFields(logrus.Fields{
+		return logger.WithFields(logrus.Fields{
 			"task":    eventContext.Task,
 			"subtask": eventContext.Subtask,
 		})
@@ -54,7 +116,7 @@ func Entry(ctx context.Context) *logrus.Entry {
 
 	// Use constants.DevLoop as the default task, as it's the highest level task we
 	// can default to if one isn't specified.
-	return logrus.WithFields(logrus.Fields{
+	return logger.WithFields(logrus.Fields{
 		"task":    constants.DevLoop,
 		"subtask": constants.SubtaskIDNone,
 	})
@@ -62,66 +124,76 @@ func Entry(ctx context.Context) *logrus.Entry {
 
 // IsDebugLevelEnabled returns true if debug level log is enabled.
 func IsDebugLevelEnabled() bool {
-	return logrus.IsLevelEnabled(logrus.DebugLevel)
+	return logger.IsLevelEnabled(logrus.DebugLevel)
 }
 
 // IsTraceLevelEnabled returns true if trace level log is enabled.
 func IsTraceLevelEnabled() bool {
-	return logrus.IsLevelEnabled(logrus.TraceLevel)
+	return logger.IsLevelEnabled(logrus.TraceLevel)
 }
 
+// New returns a new logrus.Logger.
+// We use a new instance instead of the default logrus singleton to avoid clashes with dependencies that also use logrus.
 func New() *logrus.Logger {
 	return logrus.New()
 }
 
 // KanikoLogLevel makes sure kaniko logs at least at Info level and at most Debug level (trace doesn't work with Kaniko)
 func KanikoLogLevel() logrus.Level {
-	level := logrus.GetLevel()
-	if level < logrus.InfoLevel {
+	if GetLevel() <= InfoLevel {
 		return logrus.InfoLevel
 	}
-	if level > logrus.DebugLevel {
-		return logrus.DebugLevel
-	}
-	return level
+	return logrus.DebugLevel
 }
 
 // SetupLogs sets up logrus logger for skaffold command line
 func SetupLogs(stdErr io.Writer, level string, timestamp bool, hook logrus.Hook) error {
-	logrus.SetOutput(stdErr)
+	logger.SetOutput(stdErr)
 	lvl, err := logrus.ParseLevel(level)
 	if err != nil {
 		return fmt.Errorf("parsing log level: %w", err)
 	}
-	logrus.SetLevel(lvl)
-	logrus.SetFormatter(&logrus.TextFormatter{
+	logger.SetLevel(lvl)
+	logger.SetFormatter(&logrus.TextFormatter{
 		FullTimestamp: timestamp,
 	})
-	logrus.AddHook(hook)
-	setupStdLog(logrus.StandardLogger(), lvl)
-	setupGGCRLogging(logrus.StandardLogger(), lvl)
+	logger.AddHook(hook)
+	setupStdLog(logger, lvl, stdlog.Default())
+	setupGGCRLogging(logger, lvl)
 	return nil
 }
 
+// AddHook adds a hook to the global Skaffold logger.
+func AddHook(hook logrus.Hook) {
+	logger.AddHook(hook)
+}
+
+// SetLevel sets the global Skaffold logger level.
+func SetLevel(level Level) {
+	logger.SetLevel(logrus.AllLevels[level])
+}
+
+// GetLevel returns the global Skaffold logger level.
+func GetLevel() Level {
+	return AllLevels[logger.GetLevel()]
+}
+
 // setupStdLog writes Go's standard library `log` messages to logrus at Info level.
 //
 // This function uses SetFlags() to standardize the output format.
-//
-// TODO(halvards) Add *stdlog.Logger argument (from stdlog.Default) when the build moves to Go >= 1.16.
-// We can't unit test this function in isolation when we're modifying the singleton stdlog instance.
-func setupStdLog(logger *logrus.Logger, lvl logrus.Level) {
-	stdlog.SetFlags(0)
+func setupStdLog(logger *logrus.Logger, lvl logrus.Level, stdlogger *stdlog.Logger) {
+	stdlogger.SetFlags(0)
 	if lvl >= logrus.InfoLevel {
-		stdlog.SetOutput(logger.WriterLevel(logrus.InfoLevel))
+		stdlogger.SetOutput(logger.WriterLevel(logrus.InfoLevel))
 	}
 }
 
-// setupGGCRLogging enables go-containerregistry logging, mapping its levels to logrus.
+// setupGGCRLogging enables go-containerregistry logging, mapping its levels to our levels.
 //
 // The mapping is:
-// - ggcr Warn -> logrus Error
-// - ggcr Progress -> logrus Info
-// - ggcr Debug -> logrus Trace
+// - ggcr Warn -> Skaffold Error
+// - ggcr Progress -> Skaffold Info
+// - ggcr Debug -> Skaffold Trace
 //
 // The reasons for this mapping are:
 // - `ggcr` defines `Warn` as "non-fatal errors": https://github.com/google/go-containerregistry/blob/main/pkg/logs/logs.go#L24
