@@ -99,10 +99,10 @@ func TestGetDeployer(tOuter *testing.T) {
 							map[string]latest.Pipeline{
 								"default": {},
 							},
-						),
+							[]string{"default"}),
 					}, &label.DefaultLabeller{}, &latest.KubectlDeploy{
 						Flags: latest.KubectlFlags{},
-					}, "default")).(deploy.Deployer),
+					}, nil, "default")).(deploy.Deployer),
 				}, false),
 			},
 			{
@@ -143,10 +143,10 @@ func TestGetDeployer(tOuter *testing.T) {
 						map[string]latest.Pipeline{
 							"default": {},
 						},
-					),
+						[]string{"default"}),
 				}, &label.DefaultLabeller{}, &latest.KubectlDeploy{
 					Flags: latest.KubectlFlags{},
-				}, "default")).(deploy.Deployer),
+				}, nil, "default")).(deploy.Deployer),
 			},
 			{
 				description: "apply forces creation of kubectl deployer with helm config",
@@ -164,10 +164,10 @@ func TestGetDeployer(tOuter *testing.T) {
 						map[string]latest.Pipeline{
 							"default": {},
 						},
-					),
+						[]string{"default"}),
 				}, &label.DefaultLabeller{}, &latest.KubectlDeploy{
 					Flags: latest.KubectlFlags{},
-				}, "default")).(deploy.Deployer),
+				}, nil, "default")).(deploy.Deployer),
 			},
 			{
 				description: "multiple deployers",
@@ -258,10 +258,10 @@ func TestGetDeployer(tOuter *testing.T) {
 						map[string]latest.Pipeline{
 							"default": {},
 						},
-					),
+						[]string{"default"}),
 				}, &label.DefaultLabeller{}, &latest.KubectlDeploy{
 					Flags: latest.KubectlFlags{},
-				}, "default")).(deploy.Deployer),
+				}, nil, "default")).(deploy.Deployer),
 			},
 			{
 				description: "apply works with Cloud Run",
@@ -307,7 +307,7 @@ func TestGetDeployer(tOuter *testing.T) {
 						map[string]latest.Pipeline{
 							"default": test.cfg,
 						},
-					),
+						[]string{"default"}),
 				}, &label.DefaultLabeller{}, "", false)
 
 				t.CheckError(test.shouldErr, err)
@@ -369,10 +369,10 @@ func TestGetDefaultDeployer(tOuter *testing.T) {
 						map[string]latest.Pipeline{
 							configNameForDefaultDeployer: {},
 						},
-					),
+						[]string{"default"}),
 				}, &label.DefaultLabeller{}, &latest.KubectlDeploy{
 					Flags: latest.KubectlFlags{},
-				}, configNameForDefaultDeployer)).(*kubectl.Deployer),
+				}, nil, configNameForDefaultDeployer)).(*kubectl.Deployer),
 			},
 			{
 				name: "one config with kubectl deploy, with flags",
@@ -391,13 +391,13 @@ func TestGetDefaultDeployer(tOuter *testing.T) {
 						map[string]latest.Pipeline{
 							configNameForDefaultDeployer: {},
 						},
-					),
+						[]string{"default"}),
 				}, &label.DefaultLabeller{}, &latest.KubectlDeploy{
 					Flags: latest.KubectlFlags{
 						Apply:  []string{"--foo"},
 						Global: []string{"--bar"},
 					},
-				}, configNameForDefaultDeployer)).(*kubectl.Deployer),
+				}, nil, configNameForDefaultDeployer)).(*kubectl.Deployer),
 			},
 			{
 				name: "two kubectl configs with mismatched flags should fail",
@@ -429,16 +429,17 @@ func TestGetDefaultDeployer(tOuter *testing.T) {
 						map[string]latest.Pipeline{
 							configNameForDefaultDeployer: {},
 						},
-					),
+						[]string{"default"}),
 				}, &label.DefaultLabeller{}, &latest.KubectlDeploy{
 					Flags: latest.KubectlFlags{},
-				}, configNameForDefaultDeployer)).(*kubectl.Deployer),
+				}, nil, configNameForDefaultDeployer)).(*kubectl.Deployer),
 			},
 		}
 
 		for _, test := range tests {
 			testutil.Run(tOuter, test.name, func(t *testutil.T) {
 				pipelines := map[string]latest.Pipeline{}
+				var orderedConfigNames []string
 				for configName, cfg := range test.cfgs {
 					pipeline := latest.Pipeline{
 						Deploy: latest.DeployConfig{
@@ -446,9 +447,10 @@ func TestGetDefaultDeployer(tOuter *testing.T) {
 						},
 					}
 					pipelines[configName] = pipeline
+					orderedConfigNames = append(orderedConfigNames, configName)
 				}
 				deployer, err := getDefaultDeployer(&runcontext.RunContext{
-					Pipelines: runcontext.NewPipelines(pipelines),
+					Pipelines: runcontext.NewPipelines(pipelines, orderedConfigNames),
 				}, &label.DefaultLabeller{})
 
 				t.CheckErrorAndFailNow(test.shouldErr, err)
@@ -506,12 +508,14 @@ func TestGetCloudRunDeployer(tOuter *testing.T) {
 	for _, test := range tests {
 		testutil.Run(tOuter, test.name, func(t *testutil.T) {
 			pipelines := make(map[string]latest.Pipeline)
+			var orderedConfigNames []string
 			for name, config := range test.cfgs {
 				pipelines[name] = latest.Pipeline{Deploy: latest.DeployConfig{DeployType: config}}
+				orderedConfigNames = append(orderedConfigNames, name)
 			}
 			rctx := &runcontext.RunContext{
 				Opts:      test.opts,
-				Pipelines: runcontext.NewPipelines(pipelines),
+				Pipelines: runcontext.NewPipelines(pipelines, orderedConfigNames),
 			}
 			crDeployer, err := getCloudRunDeployer(rctx, &label.DefaultLabeller{}, rctx.DeployConfigs(), "")
 			t.CheckErrorAndFailNow(test.haveErr, err)
