@@ -1,5 +1,5 @@
 /*
-Copyright 2019 The Skaffold Authors
+Copyright 2021 The Skaffold Authors
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -18,31 +18,25 @@ package runner
 
 import (
 	"context"
-	"errors"
 	"fmt"
 	"io"
+	"strconv"
 	"time"
 
-	"github.com/sirupsen/logrus"
-
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/color"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/event"
 	eventV2 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/event/v2"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/filemon"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/graph"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/instrumentation"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/portforward"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/sync"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
+	timeutil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/util/time"
 	"github.com/GoogleContainerTools/skaffold/proto/v1"
 )
 
-// ErrorConfigurationChanged is a special error that's returned when the skaffold configuration was changed.
-var ErrorConfigurationChanged = errors.New("configuration changed")
-
 var (
 	// For testing
 	fileSyncInProgress = event.FileSyncInProgress
@@ -50,63 +44,75 @@ var (
 	fileSyncSucceeded  = event.FileSyncSucceeded
 )
 
-func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *kubernetes.LogAggregator, forwarderManager portforward.Forwarder) error {
+func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer) error {
 	// never queue intents from user, even if they're not used
-	defer r.intents.reset()
+	defer r.intents.Reset()
 
-	if r.changeSet.needsReload {
+	if r.changeSet.NeedsReload() {
 		return ErrorConfigurationChanged
 	}
 
 	buildIntent, syncIntent, deployIntent := r.intents.GetIntents()
-	logrus.Tracef("dev intents: build %t, sync %t, deploy %t\n", buildIntent, syncIntent, deployIntent)
-	needsSync := syncIntent && len(r.changeSet.needsResync) > 0
-	needsBuild := buildIntent && len(r.changeSet.needsRebuild) > 0
-	needsTest := len(r.changeSet.needsRetest) > 0
-	needsDeploy := deployIntent && r.changeSet.needsRedeploy
+	log.Entry(ctx).Tracef("dev intents: build %t, sync %t, deploy %t\n", buildIntent, syncIntent, deployIntent)
+	needsBuild := buildIntent && len(r.changeSet.NeedsRebuild()) > 0
+	needsSync := syncIntent && (len(r.changeSet.NeedsResync()) > 0 || needsBuild)
+	needsTest := len(r.changeSet.NeedsRetest()) > 0
+	needsDeploy := deployIntent && (r.changeSet.NeedsRedeploy() || needsBuild)
 	if !needsSync && !needsBuild && !needsTest && !needsDeploy {
 		return nil
 	}
+	log.Entry(ctx).Debugf(" devloop: build %t, sync %t, deploy %t\n", needsBuild, needsSync, needsDeploy)
 
-	logger.Mute()
+	r.deployer.GetLogger().Mute()
 	// if any action is going to be performed, reset the monitor's changed component tracker for debouncing
 	defer r.monitor.Reset()
 	defer r.listener.LogWatchToUser(out)
+
 	event.DevLoopInProgress(r.devIteration)
-	eventV2.TaskInProgress(constants.DevLoop)
+	eventV2.InitializeState(r.runCtx)
+	eventV2.TaskInProgress(constants.DevLoop, "")
 	defer func() { r.devIteration++ }()
+	eventV2.LogMetaEvent()
+	ctx, endTrace := instrumentation.StartTrace(ctx, "doDev_DevLoopInProgress", map[string]string{
+		"devIteration": strconv.Itoa(r.devIteration),
+	})
 
 	meterUpdated := false
 	if needsSync {
+		childCtx, endTrace := instrumentation.StartTrace(ctx, "doDev_needsSync")
 		defer func() {
-			r.changeSet.resetSync()
-			r.intents.resetSync()
+			r.changeSet.ResetSync()
+			r.intents.ResetSync()
 		}()
 		instrumentation.AddDevIteration("sync")
 		meterUpdated = true
-		for _, s := range r.changeSet.needsResync {
+		for _, s := range r.changeSet.NeedsResync() {
 			fileCount := len(s.Copy) + len(s.Delete)
-			color.Default.Fprintf(out, "Syncing %d files for %s\n", fileCount, s.Image)
+			output.Default.Fprintf(out, "Syncing %d files for %s\n", fileCount, s.Image)
 			fileSyncInProgress(fileCount, s.Image)
 
-			if err := r.syncer.Sync(ctx, s); err != nil {
-				logrus.Warnln("Skipping deploy due to sync error:", err)
+			if err := r.deployer.GetSyncer().Sync(childCtx, out, s); err != nil {
+				log.Entry(ctx).Warn("Skipping deploy due to sync error:", err)
 				fileSyncFailed(fileCount, s.Image, err)
 				event.DevLoopFailedInPhase(r.devIteration, constants.Sync, err)
 				eventV2.TaskFailed(constants.DevLoop, err)
+				endTrace(instrumentation.TraceEndError(err))
+
 				return nil
 			}
 
 			fileSyncSucceeded(fileCount, s.Image)
 		}
+		endTrace()
 	}
 
 	var bRes []graph.Artifact
 	if needsBuild {
+		childCtx, endTrace := instrumentation.StartTrace(ctx, "doDev_needsBuild")
 		event.ResetStateOnBuild()
 		defer func() {
-			r.changeSet.resetBuild()
-			r.intents.resetBuild()
+			r.changeSet.ResetBuild()
+			r.intents.ResetBuild()
 		}()
 		if !meterUpdated {
 			instrumentation.AddDevIteration("build")
@@ -114,65 +120,95 @@ func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *kuber
 		}
 
 		var err error
-		bRes, err = r.Build(ctx, out, r.changeSet.needsRebuild)
+		bRes, err = r.Build(childCtx, out, r.changeSet.NeedsRebuild())
 		if err != nil {
-			logrus.Warnln("Skipping test and deploy due to build error:", err)
+			log.Entry(ctx).Warn("Skipping test and deploy due to build error:", err)
 			event.DevLoopFailedInPhase(r.devIteration, constants.Build, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace(instrumentation.TraceEndError(err))
 			return nil
 		}
-		r.changeSet.needsRedeploy = true
+		r.changeSet.Redeploy()
 		needsDeploy = deployIntent
+		endTrace()
 	}
 
 	// Trigger retest when there are newly rebuilt artifacts or untested previous artifacts; and it's not explicitly skipped
-	if (len(bRes) > 0 || needsTest) && !r.runCtx.SkipTests() {
+	if (len(bRes) > 0 || needsTest) && r.runCtx.IsTestPhaseActive() {
+		childCtx, endTrace := instrumentation.StartTrace(ctx, "doDev_needsTest")
 		event.ResetStateOnTest()
 		defer func() {
-			r.changeSet.resetTest()
+			r.changeSet.ResetTest()
 		}()
 		for _, a := range bRes {
-			delete(r.changeSet.needsRetest, a.ImageName)
+			delete(r.changeSet.NeedsRetest(), a.ImageName)
 		}
-		for _, a := range r.builds {
-			if r.changeSet.needsRetest[a.ImageName] {
+		for _, a := range r.Builds {
+			if r.changeSet.NeedsRetest()[a.ImageName] {
 				bRes = append(bRes, a)
 			}
 		}
-		if err := r.Test(ctx, out, bRes); err != nil {
+		if err := r.Test(childCtx, out, bRes); err != nil {
 			if needsDeploy {
-				logrus.Warnln("Skipping deploy due to test error:", err)
+				log.Entry(ctx).Warn("Skipping deploy due to test error:", err)
 			}
 			event.DevLoopFailedInPhase(r.devIteration, constants.Test, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace(instrumentation.TraceEndError(err))
 			return nil
 		}
+		endTrace()
 	}
 
 	if needsDeploy {
+		childCtx, endTrace := instrumentation.StartTrace(ctx, "doDev_needsDeploy")
 		event.ResetStateOnDeploy()
 		defer func() {
-			r.changeSet.resetDeploy()
-			r.intents.resetDeploy()
+			r.changeSet.ResetDeploy()
+			r.intents.ResetDeploy()
 		}()
 
-		forwarderManager.Stop()
+		log.Entry(ctx).Debug("stopping accessor")
+		r.deployer.GetAccessor().Stop()
+
+		log.Entry(ctx).Debug("stopping debugger")
+		r.deployer.GetDebugger().Stop()
+
 		if !meterUpdated {
 			instrumentation.AddDevIteration("deploy")
 		}
-		if err := r.Deploy(ctx, out, r.builds); err != nil {
-			logrus.Warnln("Skipping deploy due to error:", err)
-			event.DevLoopFailedInPhase(r.devIteration, constants.Deploy, err)
+		manifests, err := r.Render(childCtx, out, r.Builds, false)
+		if err != nil {
+			log.Entry(ctx).Warn("Skipping render due to error:", err)
+			event.DevLoopFailedInPhase(r.devIteration, constants.Render, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace(instrumentation.TraceEndError(err))
 			return nil
 		}
-		if err := forwarderManager.Start(ctx, r.runCtx.GetNamespaces()); err != nil {
-			logrus.Warnln("Port forwarding failed:", err)
+		r.deployManifests = manifests
+
+		if err := r.Deploy(childCtx, out, r.Builds, manifests); err != nil {
+			log.Entry(ctx).Warn("Skipping deploy due to error:", err)
+			event.DevLoopFailedInPhase(r.devIteration, constants.Deploy, err)
+			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace(instrumentation.TraceEndError(err))
+			return nil
 		}
+
+		if err := r.deployer.GetAccessor().Start(childCtx, out); err != nil {
+			log.Entry(ctx).Warnf("failed to start accessor: %v", err)
+		}
+
+		if err := r.deployer.GetDebugger().Start(childCtx); err != nil {
+			log.Entry(ctx).Warnf("failed to start debugger: %v", err)
+		}
+
+		endTrace()
 	}
 	event.DevLoopComplete(r.devIteration)
 	eventV2.TaskSucceeded(constants.DevLoop)
-	logger.Unmute()
+	endTrace()
+	r.deployer.GetLogger().Unmute()
 	return nil
 }
 
@@ -180,12 +216,18 @@ func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *kuber
 // config until interrupted by the user.
 func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*latest.Artifact) error {
 	event.DevLoopInProgress(r.devIteration)
-	eventV2.TaskInProgress(constants.DevLoop)
+	eventV2.InitializeState(r.runCtx)
+	eventV2.TaskInProgress(constants.DevLoop, "")
 	defer func() { r.devIteration++ }()
+	eventV2.LogMetaEvent()
+	ctx, endTrace := instrumentation.StartTrace(ctx, "Dev", map[string]string{
+		"devIteration": strconv.Itoa(r.devIteration),
+	})
+
 	g := getTransposeGraph(artifacts)
 	// Watch artifacts
 	start := time.Now()
-	color.Default.Fprintln(out, "Listing files to watch...")
+	output.Default.Fprintln(out, "Listing files to watch...")
 
 	for i := range artifacts {
 		artifact := artifacts[i]
@@ -193,7 +235,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 			continue
 		}
 
-		color.Default.Fprintf(out, " - %s\n", artifact.ImageName)
+		output.Default.Fprintf(out, " - %s\n", artifact.ImageName)
 
 		select {
 		case <-ctx.Done():
@@ -201,13 +243,13 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 		default:
 			if err := r.monitor.Register(
 				func() ([]string, error) {
-					return r.sourceDependencies.ResolveForArtifact(ctx, artifact)
+					return r.sourceDependencies.TransitiveArtifactDependencies(ctx, artifact)
 				},
 				func(e filemon.Events) {
-					s, err := sync.NewItem(ctx, artifact, e, r.builds, r.runCtx, len(g[artifact.ImageName]))
+					s, err := sync.NewItem(ctx, artifact, e, r.Builds, r.runCtx, len(g[artifact.ImageName]))
 					switch {
 					case err != nil:
-						logrus.Warnf("error adding dirty artifact to changeset: %s", err.Error())
+						log.Entry(ctx).Warnf("error adding dirty artifact to changeset: %s", err.Error())
 					case s != nil:
 						r.changeSet.AddResync(s)
 					default:
@@ -217,6 +259,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 			); err != nil {
 				event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_DEVINIT_REGISTER_BUILD_DEPS, err)
 				eventV2.TaskFailed(constants.DevLoop, err)
+				endTrace()
 				return fmt.Errorf("watching files for artifact %q: %w", artifact.ImageName, err)
 			}
 		}
@@ -226,41 +269,56 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 	for i := range artifacts {
 		artifact := artifacts[i]
 		if err := r.monitor.Register(
-			func() ([]string, error) { return r.tester.TestDependencies(artifact) },
+			func() ([]string, error) { return r.tester.TestDependencies(ctx, artifact) },
 			func(filemon.Events) { r.changeSet.AddRetest(artifact) },
 		); err != nil {
 			event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_DEVINIT_REGISTER_TEST_DEPS, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace()
 			return fmt.Errorf("watching test files: %w", err)
 		}
 	}
 
+	// Watch render configuration
+	if err := r.monitor.Register(
+		r.renderer.ManifestDeps,
+		func(filemon.Events) { r.changeSet.Redeploy() },
+	); err != nil {
+		event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_DEVINIT_REGISTER_RENDER_DEPS, err)
+		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
+		return fmt.Errorf("watching files for renderer: %w", err)
+	}
+
 	// Watch deployment configuration
 	if err := r.monitor.Register(
 		r.deployer.Dependencies,
-		func(filemon.Events) { r.changeSet.needsRedeploy = true },
+		func(filemon.Events) { r.changeSet.Redeploy() },
 	); err != nil {
 		event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_DEVINIT_REGISTER_DEPLOY_DEPS, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("watching files for deployer: %w", err)
 	}
 
 	// Watch Skaffold configuration
 	if err := r.monitor.Register(
 		func() ([]string, error) { return []string{r.runCtx.ConfigurationFile()}, nil },
-		func(filemon.Events) { r.changeSet.needsReload = true },
+		func(filemon.Events) { r.changeSet.Reload() },
 	); err != nil {
 		event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_DEVINIT_REGISTER_CONFIG_DEP, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("watching skaffold configuration %q: %w", r.runCtx.ConfigurationFile(), err)
 	}
 
-	logrus.Infoln("List generated in", util.ShowHumanizeTime(time.Since(start)))
+	log.Entry(ctx).Infoln("List generated in", timeutil.Humanize(time.Since(start)))
 
 	// Init Sync State
 	if err := sync.Init(ctx, artifacts); err != nil {
 		event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_SYNC_INIT_ERROR, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("exiting dev mode because initializing sync state failed: %w", err)
 	}
 
@@ -269,54 +327,64 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 	if err != nil {
 		event.DevLoopFailedInPhase(r.devIteration, constants.Build, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("exiting dev mode because first build failed: %w", err)
 	}
 	// First test
-	if !r.runCtx.SkipTests() {
+	if r.runCtx.IsTestPhaseActive() {
 		if err = r.Test(ctx, out, bRes); err != nil {
 			event.DevLoopFailedInPhase(r.devIteration, constants.Build, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace()
 			return fmt.Errorf("exiting dev mode because test failed after first build: %w", err)
 		}
 	}
 
-	logger := r.createLogger(out, bRes)
-	defer logger.Stop()
-
-	debugContainerManager := r.createContainerManager()
-	defer debugContainerManager.Stop()
+	defer r.deployer.GetLogger().Stop()
+	defer r.deployer.GetDebugger().Stop()
 
 	// Logs should be retrieved up to just before the deploy
-	logger.SetSince(time.Now())
+	r.deployer.GetLogger().SetSince(time.Now())
+
+	// First render
+	manifests, err := r.Render(ctx, out, r.Builds, false)
+	r.deployManifests = manifests
+	if err != nil {
+		event.DevLoopFailedInPhase(r.devIteration, constants.Render, err)
+		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
+		return fmt.Errorf("exiting dev mode because first render failed: %w", err)
+	}
 
 	// First deploy
-	if err := r.Deploy(ctx, out, r.builds); err != nil {
+	if err := r.Deploy(ctx, out, r.Builds, manifests); err != nil {
 		event.DevLoopFailedInPhase(r.devIteration, constants.Deploy, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("exiting dev mode because first deploy failed: %w", err)
 	}
 
-	forwarderManager := r.createForwarder(out)
-	defer forwarderManager.Stop()
+	defer r.deployer.GetAccessor().Stop()
 
-	if err := forwarderManager.Start(ctx, r.runCtx.GetNamespaces()); err != nil {
-		logrus.Warnln("Error starting port forwarding:", err)
+	if err := r.deployer.GetAccessor().Start(ctx, out); err != nil {
+		log.Entry(ctx).Warn("Error starting resource accessor:", err)
 	}
-	if err := debugContainerManager.Start(ctx, r.runCtx.GetNamespaces()); err != nil {
-		logrus.Warnln("Error starting debug container notification:", err)
+	if err := r.deployer.GetDebugger().Start(ctx); err != nil {
+		log.Entry(ctx).Warn("Error starting debug container notification:", err)
 	}
 	// Start printing the logs after deploy is finished
-	if err := logger.Start(ctx, r.runCtx.GetNamespaces()); err != nil {
+	if err := r.deployer.GetLogger().Start(ctx, out); err != nil {
 		return fmt.Errorf("starting logger: %w", err)
 	}
 
-	color.Yellow.Fprintln(out, "Press Ctrl+C to exit")
+	output.Yellow.Fprintln(out, "Press Ctrl+C to exit")
 
 	event.DevLoopComplete(r.devIteration)
 	eventV2.TaskSucceeded(constants.DevLoop)
+	endTrace()
 	r.devIteration++
 	return r.listener.WatchForChanges(ctx, out, func() error {
-		return r.doDev(ctx, out, logger, forwarderManager)
+		return r.doDev(ctx, out)
 	})
 }
 
