@@ -18,13 +18,15 @@ package validation
 
 import (
 	"bytes"
+	"context"
 	"fmt"
-	"io/ioutil"
+	"os"
 	"path/filepath"
 	"strings"
 	"testing"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/parser"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/render/renderer/kpt"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/defaults"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
@@ -34,12 +36,14 @@ import (
 )
 
 const (
-	samplesRoot = "../../../../docs/content/en/samples"
+	samplesRoot = "../../../../docs-v2/content/en/samples"
 )
 
 var (
+	//nolint:golint,unused
+	ignoredSamples = []string{"structureTest.yaml", "build.sh", "globalConfig.yaml", "Dockerfile.app", "Dockerfile.base"}
+	//nolint:golint,unused
 	ignoredExamples = []string{"docker-deploy", "react-reload-docker"}
-	ignoredSamples  = []string{"structureTest.yaml", "build.sh", "globalConfig.yaml", "Dockerfile.app", "Dockerfile.base"}
 )
 
 // Test that every example can be parsed and produces a valid
@@ -69,7 +73,8 @@ func TestParseSamples(t *testing.T) {
 		}
 
 		testutil.Run(t, name, func(t *testutil.T) {
-			buf, err := ioutil.ReadFile(path)
+			t.Logf("Checking %s...", path)
+			buf, err := os.ReadFile(path)
 			t.CheckNoError(err)
 
 			checkSkaffoldConfig(t, addHeader(buf))
@@ -89,6 +94,9 @@ func checkSkaffoldConfig(t *testutil.T, yaml []byte) {
 		t.CheckNoError(err)
 		cfgs = append(cfgs, cfg)
 	}
+	t.Override(&kpt.KptVersion, func(_ context.Context) (string, error) {
+		return "1.0.0-beta.13", nil
+	})
 	err = Process(cfgs, Options{CheckDeploySource: false})
 	t.CheckNoError(err)
 }
@@ -110,7 +118,7 @@ func parseConfigFiles(t *testing.T, root string) {
 		testutil.Run(t, name, func(t *testutil.T) {
 			var data []string
 			for _, path := range paths {
-				buf, err := ioutil.ReadFile(path)
+				buf, err := os.ReadFile(path)
 				t.CheckNoError(err)
 				data = append(data, string(buf))
 			}
