@@ -36,6 +36,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/parser"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/parser/configlocations"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/render/renderer/kpt"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/runcontext"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
@@ -80,11 +81,14 @@ func ProcessToErrorWithLocation(configs parser.SkaffoldConfigSet, validateConfig
 		errs = append(errs, validateSyncRules(config, config.Build.Artifacts)...)
 		errs = append(errs, validatePortForwardResources(config, config.PortForward)...)
 		errs = append(errs, validateJibPluginTypes(config, config.Build.Artifacts)...)
+		errs = append(errs, validateKoSync(config, config.Build.Artifacts)...)
 		errs = append(errs, validateLogPrefix(config, config.Deploy.Logs)...)
 		errs = append(errs, validateArtifactTypes(config, config.Build)...)
 		errs = append(errs, validateTaggingPolicy(config, config.Build)...)
 		errs = append(errs, validateCustomTest(config, config.Test)...)
 		errs = append(errs, validateGCBConfig(config, config.Build)...)
+		errs = append(errs, validateVerifyTests(config, config.Verify)...)
+		errs = append(errs, validateKptRendererVersion(config, config.Deploy, config.Render)...)
 	}
 	errs = append(errs, validateArtifactDependencies(configs)...)
 	if validateConfig.CheckDeploySource {
@@ -97,6 +101,25 @@ func ProcessToErrorWithLocation(configs parser.SkaffoldConfigSet, validateConfig
 	return errs
 }
 
+func validateKptRendererVersion(cfg *parser.SkaffoldConfigEntry, dc latest.DeployConfig, rc latest.RenderConfig) (cfgErrs []ErrorWithLocation) {
+	if dc.KptDeploy != nil {
+		return
+	}
+
+	if rc.Kpt == nil && rc.Transform == nil && rc.Validate == nil { // no kpt renderer created
+		return
+	}
+
+	if err := kpt.CheckIsProperBinVersion(context.TODO()); err != nil {
+		cfgErrs = append(cfgErrs, ErrorWithLocation{
+			Error:    err,
+			Location: cfg.YAMLInfos.LocateField(cfg, "Render"),
+		})
+	}
+
+	return
+}
+
 // Process checks if the Skaffold pipeline is valid and returns all encountered errors as a concatenated string
 func Process(configs parser.SkaffoldConfigSet, validateConfig Options) error {
 	errs := ProcessToErrorWithLocation(configs, validateConfig)
@@ -118,6 +141,8 @@ func Process(configs parser.SkaffoldConfigSet, validateConfig Options) error {
 func ProcessWithRunContext(ctx context.Context, runCtx *runcontext.RunContext) error {
 	var errs []error
 	errs = append(errs, validateDockerNetworkContainerExists(ctx, runCtx.Artifacts(), runCtx)...)
+	errs = append(errs, validateVerifyTestsExistOnVerifyCommand(runCtx.DefaultPipeline().Verify, runCtx)...)
+	errs = append(errs, validateLocationSetForCloudRun(runCtx)...)
 
 	if len(errs) == 0 {
 		return nil
@@ -385,6 +410,15 @@ func validateDockerNetworkMode(cfg *parser.SkaffoldConfigEntry, artifacts []*lat
 	return
 }
 
+// Validate that test cases exist when `verify` is called, otherwise Skaffold should error
+func validateVerifyTestsExistOnVerifyCommand(tcs []*latest.VerifyTestCase, runCtx *runcontext.RunContext) []error {
+	var errs []error
+	if len(tcs) == 0 && runCtx.Opts.Command == "verify" {
+		errs = append(errs, fmt.Errorf("verify command expects non-zero number of test cases"))
+	}
+	return errs
+}
+
 // Validates that a Docker Container with a Network Mode "container:<id|name>" points to an actually running container
 func validateDockerNetworkContainerExists(ctx context.Context, artifacts []*latest.Artifact, runCtx docker.Config) []error {
 	var errs []error
@@ -595,6 +629,31 @@ func validateJibPluginTypes(cfg *parser.SkaffoldConfigEntry, artifacts []*latest
 	return
 }
 
+// validateKoSync ensures that infer sync patterns contain the `kodata` string, since infer sync for the ko builder only supports static assets.
+func validateKoSync(cfg *parser.SkaffoldConfigEntry, artifacts []*latest.Artifact) []ErrorWithLocation {
+	var cfgErrs []ErrorWithLocation
+	for i, a := range artifacts {
+		if a.KoArtifact == nil || a.Sync == nil {
+			continue
+		}
+		if len(a.Sync.Infer) > 0 && strings.Contains(a.KoArtifact.Main, "...") {
+			cfgErrs = append(cfgErrs, ErrorWithLocation{
+				Error:    fmt.Errorf("artifact %s cannot use inferred file sync when the ko.main field contains the '...' wildcard. Instead, specify the path to the main package without using wildcards", a.ImageName),
+				Location: cfg.YAMLInfos.LocateField(cfg.Build.Artifacts[i].KoArtifact, "Main"),
+			})
+		}
+		for _, pattern := range a.Sync.Infer {
+			if !strings.Contains(pattern, "kodata") {
+				cfgErrs = append(cfgErrs, ErrorWithLocation{
+					Error:    fmt.Errorf("artifact %s has an invalid pattern %s for inferred file sync with the ko builder. The pattern must specify the 'kodata' directory. For instance, if you want to sync all static content, and your main package is in the workspace directory, you can use the pattern 'kodata/**/*'", a.ImageName, pattern),
+					Location: cfg.YAMLInfos.LocateField(cfg.Build.Artifacts[i].Sync, "Infer"),
+				})
+			}
+		}
+	}
+	return cfgErrs
+}
+
 // validateArtifactTypes checks that the artifact types are compatible with the specified builder.
 func validateArtifactTypes(cfg *parser.SkaffoldConfigEntry, bc latest.BuildConfig) []ErrorWithLocation {
 	cfgErrs := []ErrorWithLocation{}
@@ -611,7 +670,7 @@ func validateArtifactTypes(cfg *parser.SkaffoldConfigEntry, bc latest.BuildConfi
 	case bc.GoogleCloudBuild != nil:
 		for i, a := range bc.Artifacts {
 			at := misc.ArtifactType(a)
-			if at != misc.Kaniko && at != misc.Docker && at != misc.Jib && at != misc.Buildpack {
+			if at != misc.Kaniko && at != misc.Docker && at != misc.Jib && at != misc.Buildpack && at != misc.Ko {
 				cfgErrs = append(cfgErrs, ErrorWithLocation{
 					Error:    fmt.Errorf("found a '%s' artifact, which is incompatible with the 'gcb' builder:\n\n%s\n\nTo use the '%s' builder, remove the 'googleCloudBuild' stanza from the 'build' section of your configuration. For information, see https://skaffold.dev/docs/pipeline-stages/builders/", misc.ArtifactType(a), misc.FormatArtifact(a), misc.ArtifactType(a)),
 					Location: cfg.YAMLInfos.Locate(&cfg.Build.Artifacts[i].ArtifactType),
@@ -660,6 +719,35 @@ func validateLogPrefix(cfg *parser.SkaffoldConfigEntry, lc latest.LogsConfig) []
 	return nil
 }
 
+// validateVerifyTests
+// - makes sure that each test name is unique
+// - makes sure that each container name is unique
+func validateVerifyTests(cfg *parser.SkaffoldConfigEntry, tcs []*latest.VerifyTestCase) (cfgErrs []ErrorWithLocation) {
+	seenTestName := map[string]bool{}
+	seenContainerName := map[string]bool{}
+	for i, tc := range tcs {
+		if _, ok := seenTestName[tc.Name]; ok {
+			return []ErrorWithLocation{
+				{
+					Error:    fmt.Errorf("found duplicate test name '%s' in 'verify' test cases. 'verify' test case names must be unique", tc.Name),
+					Location: cfg.YAMLInfos.Locate(&cfg.Verify[i]),
+				},
+			}
+		}
+		if _, ok := seenContainerName[tc.Container.Name]; ok {
+			return []ErrorWithLocation{
+				{
+					Error:    fmt.Errorf("found duplicate container name '%s' in 'verify' test cases. 'verify' container names must be unique", tc.Container.Name),
+					Location: cfg.YAMLInfos.Locate(&cfg.Verify[i]),
+				},
+			}
+		}
+		seenTestName[tc.Name] = true
+		seenContainerName[tc.Container.Name] = true
+	}
+	return nil
+}
+
 // validateCustomTest
 // - makes sure that command is not empty
 // - makes sure that dependencies.ignore is only used in conjunction with dependencies.paths
@@ -720,16 +808,13 @@ func validateKubectlManifests(configs parser.SkaffoldConfigSet) (errs []ErrorWit
 		if c.IsRemote {
 			continue
 		}
-		if c.Deploy.KubectlDeploy == nil {
-			continue
-		}
-		if len(c.Deploy.KubectlDeploy.Manifests) == 1 && c.Deploy.KubectlDeploy.Manifests[0] == constants.DefaultKubectlManifests[0] {
+		if len(c.Render.RawK8s) == 1 && c.Render.RawK8s[0] == constants.DefaultKubectlManifests[0] {
 			log.Entry(context.TODO()).Debug("skipping validating `kubectl` deployer manifests since only the default manifest list is defined")
 			continue
 		}
 
 		// validate that manifest files referenced in config exist
-		for _, pattern := range c.Deploy.KubectlDeploy.Manifests {
+		for _, pattern := range c.Render.RawK8s {
 			if util.IsURL(pattern) {
 				continue
 			}
@@ -747,7 +832,7 @@ func validateKubectlManifests(configs parser.SkaffoldConfigSet) (errs []ErrorWit
 				msg := fmt.Sprintf("Manifest file %q referenced in skaffold config could not be found", pattern)
 				errMsg := wrapWithContext(c, ErrorWithLocation{
 					Error:    fmt.Errorf(msg),
-					Location: c.YAMLInfos.Locate(&c.Deploy.KubectlDeploy.Manifests),
+					Location: c.YAMLInfos.Locate(&c.Render.RawK8s),
 				})
 				errs = append(errs, ErrorWithLocation{
 					Error: sErrors.NewError(errMsg[0].Error,
@@ -768,3 +853,57 @@ func validateKubectlManifests(configs parser.SkaffoldConfigSet) (errs []ErrorWit
 	}
 	return errs
 }
+
+func validateLocationSetForCloudRun(rCtx *runcontext.RunContext) []error {
+	if !requiresCloudRun(rCtx) {
+		// if the current command doesn't require connecting to Cloud Run, a location isn't needed.
+		return nil
+	}
+	runDeployer := false
+	hasLocation := false
+	if rCtx.Opts.CloudRunLocation != "" {
+		hasLocation = true
+	}
+	if rCtx.Opts.CloudRunProject != "" {
+		runDeployer = true
+	} else {
+		for _, deployer := range rCtx.Pipelines.Deployers() {
+			if deployer.CloudRunDeploy != nil {
+				runDeployer = true
+				if deployer.CloudRunDeploy.Region != "" {
+					hasLocation = true
+				}
+			}
+		}
+	}
+	if runDeployer && !hasLocation {
+		return []error{sErrors.NewError(fmt.Errorf("location must be specified with Cloud Run Deployer"),
+			&proto.ActionableErr{
+				Message: "Cloud Run Location is not specified",
+				ErrCode: proto.StatusCode_INIT_CLOUD_RUN_LOCATION_ERROR,
+				Suggestions: []*proto.Suggestion{
+					{
+						SuggestionCode: proto.SuggestionCode_SPECIFY_CLOUD_RUN_LOCATION,
+						Action: "Specify a Cloud Run location via the deploy.cloudrun.region field in skaffold.yaml " +
+							"or the --cloud-run-location flag",
+					},
+				},
+			}),
+		}
+	}
+	return nil
+}
+
+// requiresCloudRun returns true if the current command needs to connect to a Cloud Run regional endpoint.
+func requiresCloudRun(rCtx *runcontext.RunContext) bool {
+	runCommands := map[string]bool{
+		"run":    true,
+		"deploy": true,
+		"debug":  true,
+		"dev":    true,
+		"delete": true,
+		"apply":  true,
+	}
+	_, ok := runCommands[rCtx.Opts.Command]
+	return ok
+}
