@@ -102,11 +102,39 @@ func TestUserAgentWithClient(t *testing.T) {
 			user:        "vsc",
 			expected:    "skaffold/1.0 (osx) vsc",
 		},
+		{
+			description: "user in allowed list",
+			platform:    "osx",
+			version:     "1.0",
+			user:        "cloud-deploy",
+			expected:    "skaffold/1.0 (osx) cloud-deploy",
+		},
+		{
+			description: "user in allowed list with valid pattern",
+			platform:    "osx",
+			version:     "1.0",
+			user:        "cloud-deploy/dev",
+			expected:    "skaffold/1.0 (osx) cloud-deploy/dev",
+		},
+		{
+			description: "user in allowed list with invalid pattern (only slash)",
+			platform:    "osx",
+			version:     "1.0",
+			user:        "cloud-deploy|dev",
+			expected:    "skaffold/1.0 (osx)",
+		},
+		{
+			description: "user in allowed list with invalid pattern (suffix required)",
+			platform:    "osx",
+			version:     "1.0",
+			user:        "cloud-deploy/",
+			expected:    "skaffold/1.0 (osx)",
+		},
 		{
 			description: "user not in allowed list",
 			platform:    "osx",
 			version:     "1.0",
-			user:        "vsc/random",
+			user:        "test-user",
 			expected:    "skaffold/1.0 (osx)",
 		},
 	}
